@@ -10,6 +10,9 @@ import { getName } from './common';
 export const getMachineRole = (obj: MachineKind | MachineSetKind | MachineDeploymentKind): string =>
   _.get(obj, ['metadata', 'labels', 'machine.openshift.io/cluster-api-machine-role']);
 
+export const getMachineInstanceType = (obj: MachineKind): string =>
+  _.get(obj, ['metadata', 'labels', 'machine.openshift.io/instance-type']);
+
 export const getMachineRegion = (obj: MachineKind): string =>
   _.get(obj, ['metadata', 'labels', 'machine.openshift.io/region']);
 
@@ -22,8 +25,3 @@ export const getMachineNode = (machine: MachineKind, nodes: NodeKind[] = []): No
   nodes.find((node) => getMachineNodeName(machine) === getName(node));
 
 export const getMachineAddresses = (machine: MachineKind) => _.get(machine, 'status.addresses', []);
-
-export const getMachineInternalIP = (machine: MachineKind) => {
-  const machineAddresses = getMachineAddresses(machine);
-  return _.get(machineAddresses.find((addr) => addr.type === 'InternalIP'), 'address');
-};
