@@ -14,6 +14,6 @@ export const isCephProvisioner = (scProvisioner: string): boolean => {
   );
 };
 
-// To check that a storage class' provisioners don't include the specified provisioner
+// To check that the storage class isn't noobaa based
 export const filterScOnProvisioner = (sc: StorageClass, provisioner: string = '') =>
-  !sc.provisioner.includes(provisioner);
+  sc.provisioner.includes(provisioner);
