@@ -1,7 +1,6 @@
 import * as React from 'react';
 import { getImageForIconClass } from '@console/internal/components/catalog/catalog-item-icon';
-import SvgDefs from '../../svg/SvgDefs';
-import { createSvgIdUrl } from '../../../utils/svg-utils';
+import { createSvgIdUrl, SVGDefs } from '@console/topology';
 
 type KnativeIconProps = {
   x: number;
@@ -13,8 +12,8 @@ type KnativeIconProps = {
 const FILTER_ID = 'KnativeIconOutlineFilterId';
 
 const KnativeIcon: React.FC<KnativeIconProps> = ({ x, y, width, height }) => (
-  <React.Fragment>
-    <SvgDefs id={FILTER_ID}>
+  <>
+    <SVGDefs id={FILTER_ID}>
       <filter id={FILTER_ID}>
         <feOffset result="nw" in="SourceAlpha" dx="-0.5" dy="-0.5" />
         <feOffset result="ne" in="SourceAlpha" dx="0.5" dy="-0.5" />
@@ -33,7 +32,7 @@ const KnativeIcon: React.FC<KnativeIconProps> = ({ x, y, width, height }) => (
           <feMergeNode in="SourceGraphic" />
         </feMerge>
       </filter>
-    </SvgDefs>
+    </SVGDefs>
     <image
       x={x}
       y={y}
@@ -42,7 +41,7 @@ const KnativeIcon: React.FC<KnativeIconProps> = ({ x, y, width, height }) => (
       xlinkHref={getImageForIconClass('icon-knative')}
       filter={createSvgIdUrl(FILTER_ID)}
     />
-  </React.Fragment>
+  </>
 );
 
 export default React.memo(KnativeIcon);
