@@ -3,7 +3,9 @@ import { Pipeline, PipelineRun } from '../utils/pipeline-augment';
 export enum DataState {
   IN_PROGRESS = 'In Progress',
   SUCCESS = 'Completed Successfully',
-  CANCELLED = 'Cancelled',
+  CANCELLED1 = 'Cancelled at stage1',
+  CANCELLED2 = 'Cancelled at stage2 paralell task',
+  CANCELLED3 = 'Cancelled at stage3 single task',
   FAILED = 'Completed But Failed',
 }
 
@@ -218,7 +220,7 @@ export const pipelineTestData: PipelineTestData = {
       },
     },
     pipelineRuns: {
-      [DataState.CANCELLED]: {
+      [DataState.CANCELLED1]: {
         apiVersion: 'tekton.dev/v1alpha1',
         kind: 'PipelineRun',
         metadata: {
@@ -251,6 +253,153 @@ export const pipelineTestData: PipelineTestData = {
           },
         },
       },
+      [DataState.CANCELLED2]: {
+        apiVersion: 'tekton.dev/v1alpha1',
+        kind: 'PipelineRun',
+        metadata: {
+          name: 'complex-pipeline-fm4hax',
+          namespace: 'tekton-pipelines',
+        },
+        spec: {
+          params: [{ name: 'APP_NAME', value: '' }],
+          pipelineRef: { name: 'complex-pipeline' },
+          resources: [
+            { name: 'app-git', resourceRef: { name: 'mapit-git' } },
+            { name: 'app-image', resourceRef: { name: 'mapit-image' } },
+          ],
+          status: 'PipelineRunCancelled',
+        },
+        status: {
+          conditions: [
+            {
+              reason: 'PipelineRunCancelled',
+              status: 'False',
+              type: 'Succeeded',
+            },
+          ],
+          startTime: '2019-12-09T08:59:05Z',
+          taskRuns: {
+            'simple-pipeline-7ergyh-build-1-cht9h': {
+              pipelineTaskName: 'build-1',
+              status: {
+                conditions: [
+                  {
+                    reason: 'TaskRunCancelled',
+                    status: 'False',
+                    type: 'Succeeded',
+                  },
+                ],
+              },
+            },
+            'simple-pipeline-7ergyh-build-2-x8jq2': {
+              pipelineTaskName: 'build-2',
+              status: {
+                conditions: [
+                  {
+                    reason: 'TaskRunCancelled',
+                    status: 'False',
+                    type: 'Succeeded',
+                  },
+                ],
+              },
+            },
+            'simple-pipeline-7ergyh-push-n2r2q': {
+              pipelineTaskName: 'push',
+              status: {
+                completionTime: '2019-12-09T08:59:26Z',
+                conditions: [
+                  {
+                    reason: 'Succeeded',
+                    status: 'True',
+                    type: 'Succeeded',
+                  },
+                ],
+              },
+            },
+          },
+        },
+      },
+      [DataState.CANCELLED3]: {
+        apiVersion: 'tekton.dev/v1alpha1',
+        kind: 'PipelineRun',
+        metadata: {
+          name: 'complex-pipeline-fm4hax',
+          namespace: 'tekton-pipelines',
+        },
+        spec: {
+          params: [{ name: 'APP_NAME', value: '' }],
+          pipelineRef: { name: 'complex-pipeline' },
+          resources: [
+            { name: 'app-git', resourceRef: { name: 'mapit-git' } },
+            { name: 'app-image', resourceRef: { name: 'mapit-image' } },
+          ],
+          status: 'PipelineRunCancelled',
+        },
+        status: {
+          conditions: [
+            {
+              reason: 'PipelineRunCancelled',
+              status: 'False',
+              type: 'Succeeded',
+            },
+          ],
+          startTime: '2019-12-10T11:18:38Z',
+          taskRuns: {
+            'simple-pipeline-haeml4-build-1-fddrb': {
+              pipelineTaskName: 'build-1',
+              status: {
+                completionTime: '2019-12-10T11:19:18Z',
+                conditions: [
+                  {
+                    reason: 'Succeeded',
+                    status: 'True',
+                    type: 'Succeeded',
+                  },
+                ],
+              },
+            },
+            'simple-pipeline-haeml4-build-2-l5scg': {
+              pipelineTaskName: 'build-2',
+              status: {
+                completionTime: '2019-12-10T11:19:19Z',
+                conditions: [
+                  {
+                    reason: 'Succeeded',
+                    status: 'True',
+                    type: 'Succeeded',
+                  },
+                ],
+                startTime: '2019-12-10T11:18:58Z',
+              },
+            },
+            'simple-pipeline-haeml4-deploy-qtpnz': {
+              pipelineTaskName: 'deploy',
+              status: {
+                conditions: [
+                  {
+                    reason: 'TaskRunCancelled',
+                    status: 'False',
+                    type: 'Succeeded',
+                  },
+                ],
+              },
+            },
+            'simple-pipeline-haeml4-push-4gj8n': {
+              pipelineTaskName: 'push',
+              status: {
+                completionTime: '2019-12-10T11:18:58Z',
+                conditions: [
+                  {
+                    reason: 'Succeeded',
+                    status: 'True',
+                    type: 'Succeeded',
+                  },
+                ],
+              },
+            },
+          },
+        },
+      },
       [DataState.IN_PROGRESS]: {
         apiVersion: 'tekton.dev/v1alpha1',
         kind: 'PipelineRun',
