@@ -1,10 +1,11 @@
 import * as React from 'react';
 import { DefaultDetailsPage } from '@console/internal/components/default-resource';
 import { DetailsPageProps } from '@console/internal/components/factory';
-import { TechPreviewBadge } from '@console/shared';
+import { getBadgeFromType } from '@console/shared';
+import { ServiceModel } from '../../models';
 
 const ServiceDetailsPage: React.FC<DetailsPageProps> = (props) => (
-  <DefaultDetailsPage {...props} badge={<TechPreviewBadge />} />
+  <DefaultDetailsPage {...props} badge={getBadgeFromType(ServiceModel.badge)} />
 );
 
 export default ServiceDetailsPage;
