@@ -1,7 +1,7 @@
 import * as React from 'react';
 import { ListPage } from '@console/internal/components/factory';
 import { referenceForModel } from '@console/internal/module/k8s';
-import { TechPreviewBadge } from '@console/shared';
+import { getBadgeFromType } from '@console/shared';
 import { ServiceModel } from '../../models';
 import ServiceList from './ServiceList';
 
@@ -9,13 +9,13 @@ export interface ServicesPageProps {
   namespace: string;
 }
 
-const ServicesPage: React.FC<ServicesPageProps> = ({ namespace }) => (
+const ServicesPage: React.FC<React.ComponentProps<typeof ListPage>> = (props) => (
   <ListPage
-    namespace={namespace}
+    {...props}
     canCreate
     kind={referenceForModel(ServiceModel)}
     ListComponent={ServiceList}
-    badge={<TechPreviewBadge />}
+    badge={getBadgeFromType(ServiceModel.badge)}
   />
 );
 
