@@ -1,3 +1,4 @@
-export * from './create-vm-wizard';
 export * from './delete-device-modal';
 export * from './modal-resource-launcher';
+export * from './vm-description-modal';
+export * from './vm-flavor-modal';
