@@ -1,5 +1,4 @@
 import * as React from 'react';
-import { getResource } from 'kubevirt-web-ui-components';
 import { navFactory } from '@console/internal/components/utils';
 import { DetailsPage } from '@console/internal/components/factory';
 import { K8sResourceKindReference } from '@console/internal/module/k8s';
@@ -7,10 +6,18 @@ import { PodModel } from '@console/internal/models';
 import { VMDisksFirehose } from '../vm-disks';
 import { VMNics } from '../vm-nics';
 import { VirtualMachineInstanceMigrationModel, VirtualMachineInstanceModel } from '../../models';
+import { getResource } from '../../utils';
+import {
+  VM_DETAIL_OVERVIEW_HREF,
+  VM_DETAIL_DISKS_HREF,
+  VM_DETAIL_NETWORKS_HREF,
+  VM_DETAIL_CONSOLES_HREF,
+} from '../../constants';
 import { VMEvents } from './vm-events';
 import { VMConsoleFirehose } from './vm-console';
 import { VMDetailsFirehose } from './vm-details';
 import { menuActionsCreator } from './menu-actions';
+import { VMDashboard } from './vm-dashboard';
 
 export const VirtualMachinesDetailsPage: React.FC<VirtualMachinesDetailsPageProps> = (props) => {
   const { name, namespace } = props;
@@ -27,26 +34,39 @@ export const VirtualMachinesDetailsPage: React.FC<VirtualMachinesDetailsPageProp
     getResource(VirtualMachineInstanceMigrationModel, { namespace, prop: 'migrations' }),
   ];
 
+  const dashboardPage = {
+    href: '', // default landing page
+    name: 'Dashboard',
+    component: VMDashboard,
+  };
+
+  const overviewPage = {
+    href: VM_DETAIL_OVERVIEW_HREF,
+    name: 'Overview',
+    component: VMDetailsFirehose,
+  };
+
   const consolePage = {
-    href: 'consoles',
+    href: VM_DETAIL_CONSOLES_HREF,
     name: 'Consoles',
     component: VMConsoleFirehose,
   };
 
   const nicsPage = {
-    href: 'nics',
+    href: VM_DETAIL_NETWORKS_HREF,
     name: 'Network Interfaces',
     component: VMNics,
   };
 
   const disksPage = {
-    href: 'disks',
+    href: VM_DETAIL_DISKS_HREF,
     name: 'Disks',
     component: VMDisksFirehose,
   };
 
   const pages = [
-    navFactory.details(VMDetailsFirehose),
+    dashboardPage,
+    overviewPage,
     navFactory.editYaml(),
     consolePage,
     navFactory.events(VMEvents),
