@@ -1,8 +1,14 @@
 import * as React from 'react';
 import { match } from 'react-router-dom';
 import * as _ from 'lodash-es';
-
-import { Firehose, HorizontalNav, PageHeading, FirehoseResource, KebabOptionsCreator } from '../utils';
+import { getBadgeFromType } from '@console/shared';
+import {
+  Firehose,
+  HorizontalNav,
+  PageHeading,
+  FirehoseResource,
+  KebabOptionsCreator,
+} from '../utils';
 import { K8sResourceKindReference, K8sResourceKind, K8sKind } from '../../module/k8s';
 import { withFallback } from '../utils/error-boundary';
 import { ErrorBoundaryFallback } from '../error';
@@ -12,14 +18,18 @@ export const DetailsPage = withFallback<DetailsPageProps>((props) => {
   const resourceKeys = _.map(props.resources, 'prop');
 
   return (
-    <Firehose resources={[{
-      kind: props.kind,
-      kindObj: props.kindObj,
-      name: props.name,
-      namespace: props.namespace,
-      isList: false,
-      prop: 'obj',
-    } as FirehoseResource].concat(props.resources || [])}>
+    <Firehose
+      resources={[
+        {
+          kind: props.kind,
+          kindObj: props.kindObj,
+          name: props.name,
+          namespace: props.namespace,
+          isList: false,
+          prop: 'obj',
+        } as FirehoseResource,
+      ].concat(props.resources || [])}
+    >
       <PageHeading
         detail={true}
         title={props.name}
@@ -27,10 +37,16 @@ export const DetailsPage = withFallback<DetailsPageProps>((props) => {
         menuActions={props.menuActions}
         buttonActions={props.buttonActions}
         kind={props.kind}
-        breadcrumbsFor={props.breadcrumbsFor ? props.breadcrumbsFor : breadcrumbsForDetailsPage(props.kindObj, props.match)}
+        breadcrumbsFor={
+          props.breadcrumbsFor
+            ? props.breadcrumbsFor
+            : breadcrumbsForDetailsPage(props.kindObj, props.match)
+        }
         resourceKeys={resourceKeys}
+        getResourceStatus={props.getResourceStatus}
         customData={props.customData}
-        badge={props.badge}
+        badge={props.badge || getBadgeFromType(props.kindObj && props.kindObj.badge)}
+        icon={props.icon}
       />
       <HorizontalNav
         pages={props.pages}
@@ -65,9 +81,11 @@ export type DetailsPageProps = {
   name?: string;
   namespace?: string;
   resources?: FirehoseResource[];
-  breadcrumbsFor?: (obj: K8sResourceKind) => {name: string, path: string}[];
+  breadcrumbsFor?: (obj: K8sResourceKind) => { name: string; path: string }[];
   customData?: any;
   badge?: React.ReactNode;
+  icon?: React.ComponentType<{ obj: K8sResourceKind }>;
+  getResourceStatus?: (resource: K8sResourceKind) => string;
 };
 
 DetailsPage.displayName = 'DetailsPage';
