@@ -2,17 +2,13 @@ import * as React from 'react';
 
 import { DaemonSetModel } from '../../models';
 import { ResourceSummary } from '../utils';
-import {
-  menuActions,
-  DaemonSetDetailsList,
-} from '../daemon-set';
-
+import { menuActions, DaemonSetDetailsList } from '../daemon-set';
 
 import { OverviewDetailsResourcesTab } from './resource-overview-page';
-import { OverviewItem } from '.';
 import { ResourceOverviewDetails } from './resource-overview-details';
+import { OverviewItem } from '@console/shared';
 
-const DaemonSetOverviewDetails: React.SFC<DaemonSetOverviewDetailsProps> = ({item}) =>
+const DaemonSetOverviewDetails: React.SFC<DaemonSetOverviewDetailsProps> = ({ item }) => (
   <div className="overview__sidebar-pane-body resource-overview__body">
     <div className="resource-overview__summary">
       <ResourceSummary resource={item.obj} showPodSelector showNodeSelector showTolerations />
@@ -20,7 +16,8 @@ const DaemonSetOverviewDetails: React.SFC<DaemonSetOverviewDetailsProps> = ({ite
     <div className="resource-overview__details">
       <DaemonSetDetailsList ds={item.obj} />
     </div>
-  </div>;
+  </div>
+);
 
 const tabs = [
   {
@@ -33,13 +30,14 @@ const tabs = [
   },
 ];
 
-export const DaemonSetOverview: React.SFC<DaemonSetOverviewProps> = ({item}) =>
+export const DaemonSetOverview: React.SFC<DaemonSetOverviewProps> = ({ item }) => (
   <ResourceOverviewDetails
     item={item}
     kindObj={DaemonSetModel}
     menuActions={menuActions}
     tabs={tabs}
-  />;
+  />
+);
 
 type DaemonSetOverviewDetailsProps = {
   item: OverviewItem;
