@@ -2,29 +2,55 @@ import * as _ from 'lodash-es';
 import * as React from 'react';
 import { connect } from 'react-redux';
 import * as classNames from 'classnames';
+import { Button } from '@patternfly/react-core';
 
 import { filterList } from '../actions/k8s';
 import { getQueryArgument, setQueryArgument } from './utils';
 
-export const CheckBox = ({title, active, number, toggle}) => {
+export const CheckBox = ({ title, active, number, toggle }) => {
   const klass = classNames('row-filter__box', {
-    'row-filter__box--active': active, 'row-filter__box--empty': !number,
+    'row-filter__box--active': active,
+    'row-filter__box--empty': !number,
   });
 
-  return <a href="#" onClick={toggle} className={klass}>
-    <span className="row-filter__number-bubble">{number}</span>{title}
-  </a>;
+  return (
+    <a href="#" onClick={toggle} className={klass}>
+      <span className="row-filter__number-bubble">{number}</span>
+      {title}
+    </a>
+  );
 };
 
-export const CheckBoxControls = ({allSelected, itemCount, selectedCount, onSelectAll, children}) => (
+export const CheckBoxControls = ({
+  allSelected,
+  itemCount,
+  selectedCount,
+  onSelectAll,
+  children,
+}) => (
   <div className="row">
     <div className="col-xs-12">
       <div className="row-filter">
         {children}
         <div className="co-m-row-filter__controls">
-          <button className="btn btn-link co-m-row-filter__selector" disabled={allSelected} type="button" onClick={onSelectAll}>Select All Filters</button>
+          <Button
+            className="co-m-row-filter__selector"
+            disabled={allSelected}
+            type="button"
+            onClick={onSelectAll}
+            variant="link"
+          >
+            Select All Filters
+          </Button>
           <span className="co-m-row-filter__items">
-            {itemCount === selectedCount ? itemCount : <>{selectedCount} of {itemCount}</>} Item{itemCount !== 1 && 's'}
+            {itemCount === selectedCount ? (
+              itemCount
+            ) : (
+              <>
+                {selectedCount} of {itemCount}
+              </>
+            )}{' '}
+            Item{itemCount !== 1 && 's'}
           </span>
         </div>
       </div>
@@ -37,7 +63,7 @@ export const storagePrefix = 'rowFilter-';
 class CheckBoxes_ extends React.Component {
   constructor(props) {
     super(props);
-    this.state = {selected: []};
+    this.state = { selected: [] };
     this.selectAll = this.selectAll.bind(this);
     this.toggle = this.toggle.bind(this);
   }
@@ -49,7 +75,7 @@ class CheckBoxes_ extends React.Component {
   componentDidMount() {
     let selected;
     try {
-      selected = (getQueryArgument(this.storageKey)).split(',');
+      selected = getQueryArgument(this.storageKey).split(',');
     } catch (ignored) {
       // ignore
     }
@@ -60,11 +86,14 @@ class CheckBoxes_ extends React.Component {
 
     const allSelected = _.isEmpty(_.xor(selected, _.map(this.props.items, 'id')));
 
-    this.setState({allSelected, selected}, () => this.applyFilter());
+    this.setState({ allSelected, selected }, () => this.applyFilter());
   }
 
   componentDidUpdate(prevProps) {
-    if (!_.isEqual(this.props.items, prevProps.items) || !_.isEqual(this.props.reduxIDs, prevProps.reduxIDs)) {
+    if (
+      !_.isEqual(this.props.items, prevProps.items) ||
+      !_.isEqual(this.props.reduxIDs, prevProps.reduxIDs)
+    ) {
       this.applyFilter();
     }
   }
@@ -73,7 +102,9 @@ class CheckBoxes_ extends React.Component {
     const all = _.map(this.props.items, 'id');
     const recognized = _.intersection(this.state.selected, all);
     if (!_.isEmpty(recognized)) {
-      this.props.reduxIDs.forEach(id => this.props.filterList(id, this.props.type, {selected: new Set(recognized), all}));
+      this.props.reduxIDs.forEach((id) =>
+        this.props.filterList(id, this.props.type, { selected: new Set(recognized), all }),
+      );
     }
   }
 
@@ -81,13 +112,13 @@ class CheckBoxes_ extends React.Component {
     // Ensure something is always active
     if (!_.isEmpty(selected)) {
       try {
-        const recognized = _.filter(selected, id => _.find(this.props.items, {id}));
+        const recognized = _.filter(selected, (id) => _.find(this.props.items, { id }));
         setQueryArgument(this.storageKey, recognized.join(','));
       } catch (ignored) {
         // ignore
       }
       const allSelected = _.isEmpty(_.xor(selected, _.map(this.props.items, 'id')));
-      this.setState({allSelected, selected}, () => this.applyFilter());
+      this.setState({ allSelected, selected }, () => this.applyFilter());
     }
   }
 
@@ -103,10 +134,14 @@ class CheckBoxes_ extends React.Component {
   }
 
   render() {
-    const {items, itemCount} = this.props;
-    const {selected} = this.state;
-    const allSelected = _.every(items, ({id}) => _.includes(selected, id));
-    const selectedCount = _.reduce(selected, (count, id) => count + (this.props.numbers[id] || 0), 0);
+    const { items, itemCount } = this.props;
+    const { selected } = this.state;
+    const allSelected = _.every(items, ({ id }) => _.includes(selected, id));
+    const selectedCount = _.reduce(
+      selected,
+      (count, id) => count + (this.props.numbers[id] || 0),
+      0,
+    );
     return (
       <CheckBoxControls
         allSelected={allSelected}
@@ -114,19 +149,22 @@ class CheckBoxes_ extends React.Component {
         selectedCount={selectedCount}
         onSelectAll={this.selectAll}
       >
-        {_.map(items, ({id, title}) =>
+        {_.map(items, ({ id, title }) => (
           <CheckBox
             key={id}
             title={title}
             number={this.props.numbers[id] || 0}
             active={_.includes(selected, id)}
-            toggle={event => this.toggle(event, id)}
+            toggle={(event) => this.toggle(event, id)}
           />
-        )}
+        ))}
       </CheckBoxControls>
     );
   }
 }
 
 /** @type {React.SFC<{items: Array, itemCount: number, numbers: any, reduxIDs: Array, selected?: Array, type: string}>} */
-export const CheckBoxes = connect(null, {filterList})(CheckBoxes_);
+export const CheckBoxes = connect(
+  null,
+  { filterList },
+)(CheckBoxes_);
