@@ -1,10 +1,18 @@
 import * as React from 'react';
 import * as _ from 'lodash-es';
 import * as PropTypes from 'prop-types';
-import {FilterSidePanel, VerticalTabs} from 'patternfly-react-extensions';
-import {EmptyState, FormControl} from 'patternfly-react';
+import { FilterSidePanel, VerticalTabs } from 'patternfly-react-extensions';
+import { FormControl } from 'patternfly-react';
+import {
+  Button,
+  EmptyState,
+  EmptyStateBody,
+  EmptyStateSecondaryActions,
+  EmptyStateVariant,
+  Title,
+} from '@patternfly/react-core';
 
-import {history} from './router';
+import { history } from './router';
 
 const CATEGORY_URL_PARAM = 'category';
 const KEYWORD_URL_PARAM = 'keyword';
@@ -20,7 +28,7 @@ const filterSubcategories = (category, item) => {
       values = [values];
     }
 
-    const intersection = [category.values, values].reduce((a, b) => a.filter(c => b.includes(c)));
+    const intersection = [category.values, values].reduce((a, b) => a.filter((c) => b.includes(c)));
     if (!_.isEmpty(intersection)) {
       return [category];
     }
@@ -29,14 +37,16 @@ const filterSubcategories = (category, item) => {
   }
 
   const matchedSubcategories = [];
-  _.forOwn(category.subcategories, subCategory => {
+  _.forOwn(category.subcategories, (subCategory) => {
     let values = _.get(item, category.field);
 
     if (!Array.isArray(values)) {
       values = [values];
     }
 
-    const valuesIntersection = [subCategory.values, values].reduce((a, b) => a.filter(c => b.includes(c)));
+    const valuesIntersection = [subCategory.values, values].reduce((a, b) =>
+      a.filter((c) => b.includes(c)),
+    );
     if (!_.isEmpty(valuesIntersection)) {
       matchedSubcategories.push(subCategory, ...filterSubcategories(subCategory, item));
     }
@@ -66,7 +76,7 @@ const addItem = (item, category, subcategory = null) => {
 
 const isCategoryEmpty = ({ items }) => _.isEmpty(items);
 
-const pruneCategoriesWithNoItems = categories => {
+const pruneCategoriesWithNoItems = (categories) => {
   if (!categories) {
     return;
   }
@@ -81,19 +91,21 @@ const pruneCategoriesWithNoItems = categories => {
 };
 
 const processSubCategories = (category, itemsSorter) => {
-  _.forOwn(category.subcategories, subcategory => {
+  _.forOwn(category.subcategories, (subcategory) => {
     if (subcategory.items) {
       subcategory.numItems = _.size(subcategory.items);
       subcategory.items = itemsSorter(subcategory.items);
       processSubCategories(subcategory, itemsSorter);
     }
     if (category.subcategories) {
-      _.each(category.items, item => {
-        const included = _.find(_.keys(category.subcategories), subcat => _.includes(category.subcategories[subcat].items, item));
+      _.each(category.items, (item) => {
+        const included = _.find(_.keys(category.subcategories), (subcat) =>
+          _.includes(category.subcategories[subcat].items, item),
+        );
         if (!included) {
           let otherCategory = _.get(category.subcategories, 'other');
           if (!otherCategory) {
-            otherCategory = {id: `${category.id}-other`, label: 'Other', items: []};
+            otherCategory = { id: `${category.id}-other`, label: 'Other', items: [] };
             category.subcategories.other = otherCategory;
           }
           otherCategory.items.push(item);
@@ -105,7 +117,7 @@ const processSubCategories = (category, itemsSorter) => {
 
 // calculate numItems per Category and subcategories, sort items
 const processCategories = (categories, itemsSorter) => {
-  _.forOwn(categories, category => {
+  _.forOwn(categories, (category) => {
     if (category.items) {
       category.numItems = _.size(category.items);
       category.items = itemsSorter(category.items);
@@ -116,10 +128,10 @@ const processCategories = (categories, itemsSorter) => {
 
 const categorize = (items, categories) => {
   // Categorize each item
-  _.each(items, item => {
+  _.each(items, (item) => {
     let itemCategorized = false;
 
-    _.each(categories, category => {
+    _.each(categories, (category) => {
       const matchedSubcategories = filterSubcategories(category, item);
       _.each(matchedSubcategories, (subcategory) => {
         addItem(item, category, subcategory); // add to subcategory & main category
@@ -141,8 +153,8 @@ const categorize = (items, categories) => {
  * (exported for test purposes)
  */
 export const categorizeItems = (items, itemsSorter, initCategories) => {
-  const allCategory = {id: 'all', label: 'All Items'};
-  const otherCategory = {id: 'other', label: 'Other'};
+  const allCategory = { id: 'all', label: 'All Items' };
+  const otherCategory = { id: 'other', label: 'Other' };
 
   const categories = {
     all: allCategory,
@@ -157,8 +169,8 @@ export const categorizeItems = (items, itemsSorter, initCategories) => {
   return categories;
 };
 
-const clearItemsFromCategories = categories => {
-  _.forOwn(categories, category => {
+const clearItemsFromCategories = (categories) => {
+  _.forOwn(categories, (category) => {
     category.numItems = 0;
     category.items = [];
     clearItemsFromCategories(category.subcategories);
@@ -172,32 +184,39 @@ const filterByKeyword = (items, filters, compFunction) => {
   }
 
   const filterString = keyword.value.toLowerCase();
-  return _.filter(items, item => compFunction(filterString, item));
+  return _.filter(items, (item) => compFunction(filterString, item));
 };
 
 const filterByGroup = (items, filters) => {
   // Filter items by each filter group
-  return _.reduce(filters, (filtered, group, key) => {
-    if (key === 'keyword') {
+  return _.reduce(
+    filters,
+    (filtered, group, key) => {
+      if (key === 'keyword') {
+        return filtered;
+      }
+
+      // Only apply active filters
+      const activeFilters = _.filter(group, 'active');
+      if (activeFilters.length) {
+        const values = _.reduce(
+          activeFilters,
+          (filterValues, filter) => {
+            filterValues.push(filter.value, ..._.get(filter, 'synonyms', []));
+            return filterValues;
+          },
+          [],
+        );
+
+        filtered[key] = _.filter(items, (item) => {
+          return values.includes(item[key]);
+        });
+      }
+
       return filtered;
-    }
-
-    // Only apply active filters
-    const activeFilters = _.filter(group, 'active');
-    if (activeFilters.length) {
-      const values = _.reduce(activeFilters, (filterValues, filter) => {
-        filterValues.push(filter.value, ..._.get(filter, 'synonyms', []));
-        return filterValues;
-      },
-      []);
-
-      filtered[key] = _.filter(items, item => {
-        return values.includes(item[key]);
-      });
-    }
-
-    return filtered;
-  }, {});
+    },
+    {},
+  );
 };
 
 const filterItems = (items, filters, keywordCompare) => {
@@ -217,7 +236,9 @@ const filterItems = (items, filters, keywordCompare) => {
 
   // Intersection of individually applied filters is all filters
   // In the case no filters are active, returns items filteredByKeyword
-  return [..._.values(filteredByGroup), filteredByKeyword].reduce((a, b) => a.filter(c => b.includes(c)));
+  return [..._.values(filteredByGroup), filteredByKeyword].reduce((a, b) =>
+    a.filter((c) => b.includes(c)),
+  );
 };
 
 const recategorizeItems = (items, itemsSorter, filters, keywordCompare, categories) => {
@@ -241,12 +262,14 @@ const hasActiveDescendant = (activeId, category) => {
     return true;
   }
 
-  return _.some(category.subcategories, subcategory => hasActiveDescendant (activeId, subcategory));
+  return _.some(category.subcategories, (subcategory) =>
+    hasActiveDescendant(activeId, subcategory),
+  );
 };
 
 const findActiveCategory = (activeId, categories) => {
   let activeCategory = null;
-  _.forOwn(categories, category => {
+  _.forOwn(categories, (category) => {
     if (activeCategory) {
       return;
     }
@@ -263,8 +286,8 @@ const findActiveCategory = (activeId, categories) => {
 const determineAvailableFilters = (initialFilters, items, filterGroups) => {
   const filters = _.cloneDeep(initialFilters);
 
-  _.each(filterGroups, field => {
-    _.each(items, item => {
+  _.each(filterGroups, (field) => {
+    _.each(items, (item) => {
       const value = item[field];
       if (value) {
         _.set(filters, [field, value], {
@@ -284,7 +307,7 @@ const getActiveFilters = (keywordFilter, groupFilters, activeFilters) => {
   activeFilters.keyword.active = !!keywordFilter;
 
   _.forOwn(groupFilters, (filterValues, filterType) => {
-    _.each(filterValues, filterValue => {
+    _.each(filterValues, (filterValue) => {
       _.set(activeFilters, [filterType, filterValue, 'active'], true);
     });
   });
@@ -293,7 +316,6 @@ const getActiveFilters = (keywordFilter, groupFilters, activeFilters) => {
 };
 
 export const updateActiveFilters = (activeFilters, filterType, id, value) => {
-
   if (filterType === 'keyword') {
     _.set(activeFilters, 'keyword.value', value);
     _.set(activeFilters, 'keyword.active', !!value);
@@ -310,31 +332,47 @@ const clearActiveFilters = (activeFilters, filterGroups) => {
   _.set(activeFilters, 'keyword.active', false);
 
   // Clear the group filters
-  _.each(filterGroups, field => {
-    _.each(_.keys(activeFilters[field]), key => _.set(activeFilters, [field, key, 'active'], false));
+  _.each(filterGroups, (field) => {
+    _.each(_.keys(activeFilters[field]), (key) =>
+      _.set(activeFilters, [field, key, 'active'], false),
+    );
   });
 
   return activeFilters;
 };
 
-const getFilterGroupCounts = (items, itemsSorter, filterGroups, selectedCategoryId, filters, categories, keywordCompare) => {
+const getFilterGroupCounts = (
+  items,
+  itemsSorter,
+  filterGroups,
+  selectedCategoryId,
+  filters,
+  categories,
+  keywordCompare,
+) => {
   // Filter only by keyword
   const filteredItems = filterByKeyword(items, filters, keywordCompare);
 
-  const categoriesForCounts = recategorizeItems(filteredItems, itemsSorter, [], keywordCompare, categories);
+  const categoriesForCounts = recategorizeItems(
+    filteredItems,
+    itemsSorter,
+    [],
+    keywordCompare,
+    categories,
+  );
 
   const activeCategory = findActiveCategory(selectedCategoryId, categoriesForCounts);
   const activeItems = activeCategory ? activeCategory.items : [];
   const newFilterCounts = {};
 
-  _.each(filterGroups, filterGroup => {
-    _.each(_.keys(filters[filterGroup]), key => {
+  _.each(filterGroups, (filterGroup) => {
+    _.each(_.keys(filters[filterGroup]), (key) => {
       const filterValues = [
         _.get(filters, [filterGroup, key, 'value']),
         ..._.get(filters, [filterGroup, key, 'synonyms'], []),
       ];
 
-      const matchedItems = _.filter(activeItems, item => {
+      const matchedItems = _.filter(activeItems, (item) => {
         return filterValues.includes(item[filterGroup]);
       });
 
@@ -345,7 +383,7 @@ const getFilterGroupCounts = (items, itemsSorter, filterGroups, selectedCategory
   return newFilterCounts;
 };
 
-const setURLParams = params => {
+const setURLParams = (params) => {
   const location = window.location;
   const url = new URL(location);
   const searchParams = `?${params.toString()}${url.hash}`;
@@ -364,7 +402,7 @@ export const updateURLParams = (filterName, value) => {
   setURLParams(params);
 };
 
-const clearFilterURLParams = selectedCategoryId => {
+const clearFilterURLParams = (selectedCategoryId) => {
   const params = new URLSearchParams();
 
   if (selectedCategoryId) {
@@ -383,7 +421,7 @@ const getActiveValuesFromURL = (availableFilters, filterGroups) => {
 
   const groupFilters = {};
 
-  _.each(filterGroups, filterGroup => {
+  _.each(filterGroups, (filterGroup) => {
     const groupFilterParam = searchParams.get(filterGroup);
     if (!groupFilterParam) {
       return;
@@ -399,13 +437,17 @@ const getActiveValuesFromURL = (availableFilters, filterGroups) => {
 
   const activeFilters = getActiveFilters(keywordFilter, groupFilters, availableFilters);
 
-  return {selectedCategoryId, activeFilters};
+  return { selectedCategoryId, activeFilters };
 };
 
-export const getFilterSearchParam = groupFilter => {
-  const activeValues = _.reduce(_.keys(groupFilter), (result, typeKey) => {
-    return groupFilter[typeKey].active ? result.concat(typeKey) : result;
-  }, []);
+export const getFilterSearchParam = (groupFilter) => {
+  const activeValues = _.reduce(
+    _.keys(groupFilter),
+    (result, typeKey) => {
+      return groupFilter[typeKey].active ? result.concat(typeKey) : result;
+    },
+    [],
+  );
 
   return _.isEmpty(activeValues) ? '' : JSON.stringify(activeValues);
 };
@@ -420,7 +462,7 @@ const defaultFilters = {
 export class TileViewPage extends React.Component {
   constructor(props) {
     super(props);
-    const {items, itemsSorter, getAvailableCategories} = this.props;
+    const { items, itemsSorter, getAvailableCategories } = this.props;
 
     const categories = getAvailableCategories(items);
 
@@ -439,14 +481,20 @@ export class TileViewPage extends React.Component {
   }
 
   componentDidMount() {
-    const {items, filterGroups, getAvailableFilters} = this.props;
-    const {categories} = this.state;
+    const { items, filterGroups, getAvailableFilters } = this.props;
+    const { categories } = this.state;
     const availableFilters = getAvailableFilters(defaultFilters, items, filterGroups);
 
     const activeValues = getActiveValuesFromURL(availableFilters, filterGroups);
 
-    this.setState({...this.getUpdatedState(categories, activeValues.selectedCategoryId, activeValues.activeFilters) });
-    this.filterByKeywordInput.focus({preventScroll: true});
+    this.setState({
+      ...this.getUpdatedState(
+        categories,
+        activeValues.selectedCategoryId,
+        activeValues.activeFilters,
+      ),
+    });
+    this.filterByKeywordInput.focus({ preventScroll: true });
   }
 
   componentWillUnmount() {
@@ -455,32 +503,43 @@ export class TileViewPage extends React.Component {
 
   componentDidUpdate(prevProps) {
     const { activeFilters, selectedCategoryId } = this.state;
-    const { items, itemsSorter, filterGroups, getAvailableCategories, getAvailableFilters } = this.props;
+    const {
+      items,
+      itemsSorter,
+      filterGroups,
+      getAvailableCategories,
+      getAvailableFilters,
+    } = this.props;
 
     if (!_.isEqual(items, prevProps.items)) {
       const availableFilters = getAvailableFilters(defaultFilters, items, filterGroups);
       const availableCategories = getAvailableCategories(items);
       const categories = categorizeItems(items, itemsSorter, availableCategories);
 
-      const newActiveFilters = _.reduce(availableFilters, (updatedFilters, filterGroup, filterGroupName) => {
-        if (filterGroupName === 'keyword') {
-          updatedFilters.keyword = activeFilters.keyword;
+      const newActiveFilters = _.reduce(
+        availableFilters,
+        (updatedFilters, filterGroup, filterGroupName) => {
+          if (filterGroupName === 'keyword') {
+            updatedFilters.keyword = activeFilters.keyword;
+            return updatedFilters;
+          }
+
+          _.each(filterGroup, (filterItem, filterItemName) => {
+            updatedFilters[filterGroupName][filterItemName].active = _.get(
+              activeFilters,
+              [filterGroupName, filterItemName, 'active'],
+              false,
+            );
+          });
+
           return updatedFilters;
-        }
+        },
+        availableFilters,
+      );
 
-        _.each(filterGroup, (filterItem, filterItemName) => {
-          updatedFilters[filterGroupName][filterItemName].active = _.get(
-            activeFilters,
-            [filterGroupName, filterItemName, 'active'],
-            false)
-          ;
-        });
-
-        return updatedFilters;
-      },
-      availableFilters);
-
-      this.updateMountedState({...this.getUpdatedState(categories, selectedCategoryId, newActiveFilters)});
+      this.updateMountedState({
+        ...this.getUpdatedState(categories, selectedCategoryId, newActiveFilters),
+      });
     }
   }
 
@@ -491,13 +550,27 @@ export class TileViewPage extends React.Component {
       return;
     }
 
-    const newCategories = recategorizeItems(items, itemsSorter, activeFilters, keywordCompare, categories);
+    const newCategories = recategorizeItems(
+      items,
+      itemsSorter,
+      activeFilters,
+      keywordCompare,
+      categories,
+    );
 
     return {
       activeFilters,
       selectedCategoryId,
       categories: newCategories,
-      filterCounts: getFilterGroupCounts(items, itemsSorter, filterGroups, selectedCategoryId, activeFilters, newCategories, keywordCompare),
+      filterCounts: getFilterGroupCounts(
+        items,
+        itemsSorter,
+        filterGroups,
+        selectedCategoryId,
+        activeFilters,
+        newCategories,
+        keywordCompare,
+      ),
     };
   }
 
@@ -518,13 +591,13 @@ export class TileViewPage extends React.Component {
 
     this.updateMountedState(this.getUpdatedState(categories, selectedCategoryId, clearedFilters));
 
-    this.filterByKeywordInput.focus({preventScroll: true});
+    this.filterByKeywordInput.focus({ preventScroll: true });
   }
 
   selectCategory(categoryId) {
     const { activeFilters, categories } = this.state;
 
-    updateURLParams (CATEGORY_URL_PARAM, categoryId);
+    updateURLParams(CATEGORY_URL_PARAM, categoryId);
     this.updateMountedState(this.getUpdatedState(categories, categoryId, activeFilters));
   }
 
@@ -557,7 +630,7 @@ export class TileViewPage extends React.Component {
     const { filterGroupsShowAll } = this.state;
     const updatedShow = _.clone(filterGroupsShowAll);
     _.set(updatedShow, groupName, !_.get(filterGroupsShowAll, groupName, false));
-    this.setState({filterGroupsShowAll: updatedShow });
+    this.setState({ filterGroupsShowAll: updatedShow });
   }
 
   renderTabs(category, selectedCategoryId) {
@@ -565,32 +638,48 @@ export class TileViewPage extends React.Component {
     const active = id === selectedCategoryId;
     const shown = id === 'all';
 
-    const tabClasses = `text-capitalize${!numItems ? ' co-catalog-tab__empty': ''}`;
-    return <VerticalTabs.Tab
-      key={id}
-      title={label}
-      active={active}
-      className={tabClasses}
-      onActivate={() => this.selectCategory(id)}
-      hasActiveDescendant={hasActiveDescendant(selectedCategoryId, category)}
-      shown={shown}>
-      {subcategories && <VerticalTabs restrictTabs activeTab={isActiveTab(selectedCategoryId, category)}>
-        {_.map(subcategories, subcategory => this.renderTabs(subcategory, selectedCategoryId))}
-      </VerticalTabs>}
-    </VerticalTabs.Tab>;
+    const tabClasses = `text-capitalize${!numItems ? ' co-catalog-tab__empty' : ''}`;
+    return (
+      <VerticalTabs.Tab
+        key={id}
+        title={label}
+        active={active}
+        className={tabClasses}
+        onActivate={() => this.selectCategory(id)}
+        hasActiveDescendant={hasActiveDescendant(selectedCategoryId, category)}
+        shown={shown}
+      >
+        {subcategories && (
+          <VerticalTabs restrictTabs activeTab={isActiveTab(selectedCategoryId, category)}>
+            {_.map(subcategories, (subcategory) =>
+              this.renderTabs(subcategory, selectedCategoryId),
+            )}
+          </VerticalTabs>
+        )}
+      </VerticalTabs.Tab>
+    );
   }
 
   renderCategoryTabs(selectedCategoryId) {
     const { categories } = this.state;
     const activeTab = _.has(categories, selectedCategoryId);
 
-    return <VerticalTabs restrictTabs activeTab={activeTab} shown="true">
-      {_.map(categories, category => this.renderTabs(category, selectedCategoryId))}
-    </VerticalTabs>;
+    return (
+      <VerticalTabs restrictTabs activeTab={activeTab} shown="true">
+        {_.map(categories, (category) => this.renderTabs(category, selectedCategoryId))}
+      </VerticalTabs>
+    );
   }
 
-  // eslint-disable-next-line @typescript-eslint/no-unused-vars, no-unused-vars
-  renderFilterGroup(filterGroup, groupName, activeFilters, filterCounts, onFilterChange, onUpdateFilters) {
+  renderFilterGroup(
+    filterGroup,
+    groupName,
+    activeFilters,
+    filterCounts,
+    onFilterChange,
+    // eslint-disable-next-line @typescript-eslint/no-unused-vars, no-unused-vars
+    onUpdateFilters,
+  ) {
     const { filterGroupNameMap } = this.props;
     const { filterGroupsShowAll } = this.state;
 
@@ -604,16 +693,18 @@ export class TileViewPage extends React.Component {
       >
         {_.map(filterGroup, (filter, filterName) => {
           const { label, active } = filter;
-          return <FilterSidePanel.CategoryItem
-            key={filterName}
-            count={_.get(filterCounts, [groupName, filterName], 0)}
-            checked={active}
-            onChange={e => onFilterChange(groupName, filterName, e.target.checked)}
-            title={label}
-            data-test={`${groupName}-${_.kebabCase(filterName)}`}
-          >
-            {label}
-          </FilterSidePanel.CategoryItem>;
+          return (
+            <FilterSidePanel.CategoryItem
+              key={filterName}
+              count={_.get(filterCounts, [groupName, filterName], 0)}
+              checked={active}
+              onChange={(e) => onFilterChange(groupName, filterName, e.target.checked)}
+              title={label}
+              data-test={`${groupName}-${_.kebabCase(filterName)}`}
+            >
+              {label}
+            </FilterSidePanel.CategoryItem>
+          );
         })}
       </FilterSidePanel.Category>
     );
@@ -631,7 +722,14 @@ export class TileViewPage extends React.Component {
           if (groupName === 'keyword') {
             return;
           }
-          return renderFilterGroup(filterGroup, groupName, activeFilters, filterCounts, this.onFilterChange, this.onUpdateFilters);
+          return renderFilterGroup(
+            filterGroup,
+            groupName,
+            activeFilters,
+            filterCounts,
+            this.onFilterChange,
+            this.onUpdateFilters,
+          );
         })}
       </FilterSidePanel>
     );
@@ -640,16 +738,20 @@ export class TileViewPage extends React.Component {
   renderEmptyState() {
     const { emptyStateTitle, emptyStateInfo } = this.props;
     return (
-      <EmptyState className="co-catalog-page__no-filter-results">
-        <EmptyState.Title className="co-catalog-page__no-filter-results-title" aria-level="2">
+      <EmptyState variant={EmptyStateVariant.full}>
+        <Title headingLevel="h2" size="lg">
           {emptyStateTitle}
-        </EmptyState.Title>
-        <EmptyState.Info className="text-secondary">
-          {emptyStateInfo}
-        </EmptyState.Info>
-        <EmptyState.Help>
-          <button type="button" className="btn btn-link" onClick={() => this.clearFilters()}>Clear All Filters</button>
-        </EmptyState.Help>
+        </Title>
+        <EmptyStateBody>{emptyStateInfo}</EmptyStateBody>
+        <EmptyStateSecondaryActions>
+          <Button
+            variant="link"
+            onClick={() => this.clearFilters()}
+            data-test-id="catalog-clear-filters"
+          >
+            Clear All Filters
+          </Button>
+        </EmptyStateSecondaryActions>
       </EmptyState>
     );
   }
@@ -665,8 +767,8 @@ export class TileViewPage extends React.Component {
     return (
       <div className="co-catalog-page">
         <div className="co-catalog-page__tabs">
-          { this.renderCategoryTabs(activeCategory.id) }
-          { this.renderSidePanel() }
+          {this.renderCategoryTabs(activeCategory.id)}
+          {this.renderSidePanel()}
         </div>
         <div className="co-catalog-page__content">
           <div className="co-catalog-page__header">
@@ -675,18 +777,18 @@ export class TileViewPage extends React.Component {
               <FormControl
                 className="co-catalog-page__input"
                 type="text"
-                inputRef={(ref) => this.filterByKeywordInput = ref}
+                inputRef={(ref) => (this.filterByKeywordInput = ref)}
                 placeholder="Filter by keyword..."
                 bsClass="pf-c-form-control"
                 value={activeFilters.keyword.value}
-                onChange={e => this.onKeywordChange(e.target.value)}
+                onChange={(e) => this.onKeywordChange(e.target.value)}
               />
               <div className="co-catalog-page__num-items">{activeCategory.numItems} items</div>
             </div>
           </div>
           {activeCategory.numItems > 0 && (
             <div className="catalog-tile-view-pf catalog-tile-view-pf-no-categories">
-              {_.map(activeCategory.items, item => renderTile(item))}
+              {_.map(activeCategory.items, (item) => renderTile(item))}
             </div>
           )}
           {activeCategory.numItems === 0 && this.renderEmptyState()}
