@@ -8,12 +8,18 @@ import * as plugins from '../plugins';
  * Sample YAML manifests for some of the statically-defined Kubernetes models.
  */
 export const baseTemplates = ImmutableMap<GroupVersionKind, ImmutableMap<string, string>>()
-  .setIn(['DEFAULT', 'default'], `
+  .setIn(
+    ['DEFAULT', 'default'],
+    `
 apiVersion: ''
 kind: ''
 metadata:
   name: example
-`).setIn([referenceForModel(k8sModels.NetworkPolicyModel), 'default'], `
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.NetworkPolicyModel), 'default'],
+    `
 apiVersion: networking.k8s.io/v1
 kind: NetworkPolicy
 metadata:
@@ -34,7 +40,11 @@ spec:
     ports:
     - protocol: TCP
       port: 6379
-`).setIn([referenceForModel(k8sModels.NetworkPolicyModel), 'deny-other-namespaces'], `
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.NetworkPolicyModel), 'deny-other-namespaces'],
+    `
 apiVersion: networking.k8s.io/v1
 kind: NetworkPolicy
 metadata:
@@ -45,7 +55,11 @@ spec:
   ingress:
   - from:
     - podSelector: {}
-`).setIn([referenceForModel(k8sModels.NetworkPolicyModel), 'db-or-api-allow-app'], `
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.NetworkPolicyModel), 'db-or-api-allow-app'],
+    `
 apiVersion: networking.k8s.io/v1
 kind: NetworkPolicy
 metadata:
@@ -60,7 +74,11 @@ spec:
       - podSelector:
           matchLabels:
             app: mail
-`).setIn([referenceForModel(k8sModels.NetworkPolicyModel), 'api-allow-http-and-https'], `
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.NetworkPolicyModel), 'api-allow-http-and-https'],
+    `
 apiVersion: networking.k8s.io/v1
 kind: NetworkPolicy
 metadata:
@@ -80,7 +98,11 @@ spec:
           port: 80
         - protocol: TCP
           port: 443
-`).setIn([referenceForModel(k8sModels.NetworkPolicyModel), 'default-deny-all'], `
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.NetworkPolicyModel), 'default-deny-all'],
+    `
 apiVersion: networking.k8s.io/v1
 kind: NetworkPolicy
 metadata:
@@ -88,7 +110,11 @@ metadata:
   namespace: target-ns
 spec:
   podSelector:
-`).setIn([referenceForModel(k8sModels.NetworkPolicyModel), 'web-allow-external'], `
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.NetworkPolicyModel), 'web-allow-external'],
+    `
 apiVersion: networking.k8s.io/v1
 kind: NetworkPolicy
 metadata:
@@ -100,7 +126,11 @@ spec:
       app: web
   ingress:
   - {}
-`).setIn([referenceForModel(k8sModels.NetworkPolicyModel), 'web-db-allow-all-ns'], `
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.NetworkPolicyModel), 'web-db-allow-all-ns'],
+    `
 apiVersion: networking.k8s.io/v1
 kind: NetworkPolicy
 metadata:
@@ -113,7 +143,11 @@ spec:
   ingress:
     - from:
       - namespaceSelector: {}
-`).setIn([referenceForModel(k8sModels.NetworkPolicyModel), 'web-allow-production'], `
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.NetworkPolicyModel), 'web-allow-production'],
+    `
 apiVersion: networking.k8s.io/v1
 kind: NetworkPolicy
 metadata:
@@ -128,7 +162,11 @@ spec:
       - namespaceSelector:
           matchLabels:
             env: production
-`).setIn([referenceForModel(k8sModels.BuildConfigModel), 'default'], `
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.BuildConfigModel), 'default'],
+    `
 apiVersion: build.openshift.io/v1
 kind: BuildConfig
 metadata:
@@ -151,7 +189,11 @@ spec:
   - type: ImageChange
     imageChange: {}
   - type: ConfigChange
-`).setIn([referenceForModel(k8sModels.ChargebackReportModel), 'default'], `
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.ChargebackReportModel), 'default'],
+    `
 apiVersion: metering.openshift.io/v1
 kind: Report
 metadata:
@@ -162,8 +204,27 @@ spec:
   reportingStart: '2019-01-01T00:00:00Z'
   reportingEnd: '2019-12-30T23:59:59Z'
   runImmediately: true
-`)
-  .setIn([referenceForModel(k8sModels.DeploymentModel), 'default'], `
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.ReportQueryModel), 'default'],
+    `
+apiVersion: metering.openshift.io/v1
+kind: ReportQuery
+metadata:
+  name: example
+  namespace: openshift-metering
+spec:
+  columns:
+  - name: the_time
+    type: timestamp
+  query: |
+    SELECT now() AS the_time;
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.DeploymentModel), 'default'],
+    `
 apiVersion: apps/v1
 kind: Deployment
 metadata:
@@ -183,7 +244,11 @@ spec:
         image: openshift/hello-openshift
         ports:
         - containerPort: 8080
-`).setIn([referenceForModel(k8sModels.ConfigMapModel), 'default'], `
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.ConfigMapModel), 'default'],
+    `
 apiVersion: v1
 kind: ConfigMap
 metadata:
@@ -196,7 +261,11 @@ data:
     property.1=value-1
     property.2=value-2
     property.3=value-3
-`).setIn([referenceForModel(k8sModels.CronJobModel), 'default'], `
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.CronJobModel), 'default'],
+    `
 apiVersion: batch/v1beta1
 kind: CronJob
 metadata:
@@ -215,7 +284,11 @@ spec:
             - -c
             - date; echo Hello from the Kubernetes cluster
           restartPolicy: OnFailure
-`).setIn([referenceForModel(k8sModels.CustomResourceDefinitionModel), 'default'], `
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.CustomResourceDefinitionModel), 'default'],
+    `
 apiVersion: apiextensions.k8s.io/v1beta1
 kind: CustomResourceDefinition
 metadata:
@@ -238,7 +311,11 @@ spec:
     # shortNames allow shorter string to match your resource on the CLI
     shortNames:
     - ct
-`).setIn([referenceForModel(k8sModels.DeploymentConfigModel), 'default'], `
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.DeploymentConfigModel), 'default'],
+    `
 apiVersion: apps.openshift.io/v1
 kind: DeploymentConfig
 metadata:
@@ -257,7 +334,11 @@ spec:
         image: openshift/hello-openshift
         ports:
         - containerPort: 8080
-`).setIn([referenceForModel(k8sModels.PersistentVolumeModel), 'default'], `
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.PersistentVolumeModel), 'default'],
+    `
 apiVersion: v1
 kind: PersistentVolume
 metadata:
@@ -267,12 +348,16 @@ spec:
     storage: 5Gi
   accessModes:
     - ReadWriteOnce
-  persistentVolumeReclaimPolicy: Recycle
+  persistentVolumeReclaimPolicy: Retain
   storageClassName: slow
   nfs:
     path: /tmp
     server: 172.17.0.2
-`).setIn([referenceForModel(k8sModels.HorizontalPodAutoscalerModel), 'default'], `
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.HorizontalPodAutoscalerModel), 'default'],
+    `
 apiVersion: autoscaling/v2beta1
 kind: HorizontalPodAutoscaler
 metadata:
@@ -289,7 +374,11 @@ spec:
     resource:
       name: cpu
       targetAverageUtilization: 50
-`).setIn([referenceForModel(k8sModels.PodModel), 'default'], `
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.PodModel), 'default'],
+    `
 apiVersion: v1
 kind: Pod
 metadata:
@@ -302,8 +391,12 @@ spec:
       image: openshift/hello-openshift
       ports:
         - containerPort: 8080
-`).setIn([referenceForModel(k8sModels.IngressModel), 'default'], `
-apiVersion: extensions/v1beta1
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.IngressModel), 'default'],
+    `
+apiVersion: networking.k8s.io/v1beta1
 kind: Ingress
 metadata:
   name: example
@@ -316,7 +409,11 @@ spec:
         backend:
           serviceName: test
           servicePort: 80
-`).setIn([referenceForModel(k8sModels.JobModel), 'default'], `
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.JobModel), 'default'],
+    `
 apiVersion: batch/v1
 kind: Job
 metadata:
@@ -332,12 +429,20 @@ spec:
         image: perl
         command: ["perl",  "-Mbignum=bpi", "-wle", "print bpi(2000)"]
       restartPolicy: Never
-`).setIn([referenceForModel(k8sModels.ImageStreamModel), 'default'], `
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.ImageStreamModel), 'default'],
+    `
 apiVersion: image.openshift.io/v1
 kind: ImageStream
 metadata:
   name: example
-`).setIn([referenceForModel(k8sModels.RoleBindingModel), 'default'], `
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.RoleBindingModel), 'default'],
+    `
 apiVersion: rbac.authorization.k8s.io/v1
 kind: RoleBinding
 metadata:
@@ -350,7 +455,11 @@ roleRef:
   kind: ClusterRole
   name: view
   apiGroup: rbac.authorization.k8s.io
-`).setIn([referenceForModel(k8sModels.RoleModel), 'default'], `apiVersion: rbac.authorization.k8s.io/v1
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.RoleModel), 'default'],
+    `apiVersion: rbac.authorization.k8s.io/v1
 kind: Role
 metadata:
   name: example
@@ -358,7 +467,11 @@ rules:
 - apiGroups: [""] # "" indicates the core API group
   resources: ["pods"]
   verbs: ["get", "watch", "list"]
-`).setIn([referenceForModel(k8sModels.RoleModel), 'read-pods-within-ns'], `
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.RoleModel), 'read-pods-within-ns'],
+    `
 apiVersion: rbac.authorization.k8s.io/v1
 kind: Role
 metadata:
@@ -368,7 +481,11 @@ rules:
 - apiGroups: [""]
   resources: ["pods"]
   verbs: ["get", "list", "watch"]
-`).setIn([referenceForModel(k8sModels.RoleModel), 'read-write-deployment-in-ext-and-apps-apis'], `
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.RoleModel), 'read-write-deployment-in-ext-and-apps-apis'],
+    `
 apiVersion: rbac.authorization.k8s.io/v1
 kind: Role
 metadata:
@@ -378,8 +495,11 @@ rules:
 - apiGroups: ["extensions", "apps"]
   resources: ["deployments"]
   verbs: ["get", "list", "watch", "create", "update", "patch", "delete"]
-`)
-  .setIn([referenceForModel(k8sModels.RoleModel), 'read-pods-and-read-write-jobs'], `apiVersion: rbac.authorization.k8s.io/v1
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.RoleModel), 'read-pods-and-read-write-jobs'],
+    `apiVersion: rbac.authorization.k8s.io/v1
 kind: Role
 metadata:
   name: read-pods-and-read-write-jobs
@@ -391,8 +511,11 @@ rules:
 - apiGroups: ["batch", "extensions"]
   resources: ["jobs"]
   verbs: ["get", "list", "watch", "create", "update", "patch", "delete"]
-`)
-  .setIn([referenceForModel(k8sModels.RoleModel), 'read-configmap-within-ns'], `
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.RoleModel), 'read-configmap-within-ns'],
+    `
 apiVersion: rbac.authorization.k8s.io/v1
 kind: Role
 metadata:
@@ -403,7 +526,11 @@ rules:
   resources: ["configmaps"]
   resourceNames: ["my-config"]
   verbs: ["get"]
-`).setIn([referenceForModel(k8sModels.ClusterRoleModel), 'read-nodes'], `
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.ClusterRoleModel), 'read-nodes'],
+    `
 apiVersion: rbac.authorization.k8s.io/v1
 kind: ClusterRole
 metadata:
@@ -413,7 +540,11 @@ rules:
 - apiGroups: [""]
   resources: ["nodes"]
   verbs: ["get", "list", "watch"]
-`).setIn([referenceForModel(k8sModels.ClusterRoleModel), 'get-and-post-to-non-resource-endpoints'], `
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.ClusterRoleModel), 'get-and-post-to-non-resource-endpoints'],
+    `
 apiVersion: rbac.authorization.k8s.io/v1
 kind: ClusterRole
 metadata:
@@ -422,7 +553,11 @@ metadata:
 rules:
 - nonResourceURLs: ["/healthz", "/healthz/*"] # '*' in a nonResourceURL is a suffix glob match
   verbs: ["get", "post"]
-`).setIn([referenceForModel(k8sModels.ServiceModel), 'default'], `
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.ServiceModel), 'default'],
+    `
 apiVersion: v1
 kind: Service
 metadata:
@@ -434,7 +569,11 @@ spec:
   - protocol: TCP
     port: 80
     targetPort: 9376
-`).setIn([referenceForModel(k8sModels.DaemonSetModel), 'default'], `
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.DaemonSetModel), 'default'],
+    `
 apiVersion: apps/v1
 kind: DaemonSet
 metadata:
@@ -453,7 +592,11 @@ spec:
         image: openshift/hello-openshift
         ports:
         - containerPort: 8080
-`).setIn([referenceForModel(k8sModels.PersistentVolumeClaimModel), 'default'], `
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.PersistentVolumeClaimModel), 'default'],
+    `
 apiVersion: v1
 kind: PersistentVolumeClaim
 metadata:
@@ -464,7 +607,11 @@ spec:
   resources:
     requests:
       storage: 1Gi
-`).setIn([referenceForModel(k8sModels.ResourceQuotaModel), 'default'], `
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.ResourceQuotaModel), 'default'],
+    `
 apiVersion: v1
 kind: ResourceQuota
 metadata:
@@ -476,7 +623,11 @@ spec:
     requests.memory: 1Gi
     limits.cpu: "2"
     limits.memory: 2Gi
-`).setIn([referenceForModel(k8sModels.LimitRangeModel), 'default'], `
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.LimitRangeModel), 'default'],
+    `
 apiVersion: v1
 kind: LimitRange
 metadata:
@@ -488,7 +639,11 @@ spec:
     defaultRequest:
       memory: 256Mi
     type: Container
-`).setIn([referenceForModel(k8sModels.StatefulSetModel), 'default'], `
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.StatefulSetModel), 'default'],
+    `
 apiVersion: apps/v1
 kind: StatefulSet
 metadata:
@@ -523,19 +678,31 @@ spec:
       resources:
         requests:
           storage: 1Gi
-`).setIn([referenceForModel(k8sModels.StorageClassModel), 'default'], `
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.StorageClassModel), 'default'],
+    `
 apiVersion: storage.k8s.io/v1
 kind: StorageClass
 metadata:
   name: example
 provisioner: my-provisioner
 reclaimPolicy: Delete
-`).setIn([referenceForModel(k8sModels.ServiceAccountModel), 'default'], `
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.ServiceAccountModel), 'default'],
+    `
 apiVersion: v1
 kind: ServiceAccount
 metadata:
   name: example
-`).setIn([referenceForModel(k8sModels.SecretModel), 'default'], `
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.SecretModel), 'default'],
+    `
 apiVersion: v1
 kind: Secret
 metadata:
@@ -544,7 +711,11 @@ type: Opaque
 stringData:
   username: admin
   password: opensesame
-`).setIn([referenceForModel(k8sModels.ReplicaSetModel), 'default'], `
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.ReplicaSetModel), 'default'],
+    `
 apiVersion: apps/v1
 kind: ReplicaSet
 metadata:
@@ -565,7 +736,11 @@ spec:
         image: openshift/hello-openshift
         ports:
         - containerPort: 8080
-`).setIn([referenceForModel(k8sModels.RouteModel), 'default'], `
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.RouteModel), 'default'],
+    `
 apiVersion: route.openshift.io/v1
 kind: Route
 metadata:
@@ -577,7 +752,11 @@ spec:
     name: example
   port:
     targetPort: 80
-`).setIn([referenceForModel(k8sModels.ReplicationControllerModel), 'default'], `
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.ReplicationControllerModel), 'default'],
+    `
 apiVersion: v1
 kind: ReplicationController
 metadata:
@@ -597,7 +776,11 @@ spec:
         image: openshift/hello-openshift
         ports:
         - containerPort: 8080
-`).setIn([referenceForModel(k8sModels.BuildConfigModel), 'docker-build'], `
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.BuildConfigModel), 'docker-build'],
+    `
 apiVersion: build.openshift.io/v1
 kind: BuildConfig
 metadata:
@@ -637,7 +820,11 @@ spec:
     - exec
     - rake
     - test
-`).setIn([referenceForModel(k8sModels.BuildConfigModel), 's2i-build'], `apiVersion: build.openshift.io/v1
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.BuildConfigModel), 's2i-build'],
+    `apiVersion: build.openshift.io/v1
 kind: BuildConfig
 metadata:
   name: s2i-build
@@ -664,14 +851,34 @@ spec:
   - type: ImageChange
     imageChange: {}
   - type: ConfigChange
-`).setIn([referenceForModel(k8sModels.ClusterServiceBrokerModel), 'default'], `
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.GroupModel), 'default'],
+    `
+apiVersion: user.openshift.io/v1
+kind: Group
+metadata:
+  name: example
+users:
+- user1
+- user2
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.ClusterServiceBrokerModel), 'default'],
+    `
 apiVersion: servicecatalog.k8s.io/v1beta1
 kind: ClusterServiceBroker
 metadata:
   name: example-cluster-service-broker
 spec:
   url: https://example.com/broker/
-`).setIn([referenceForModel(k8sModels.ResourceQuotaModel), 'rq-compute'], `
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.ResourceQuotaModel), 'rq-compute'],
+    `
 apiVersion: v1
 kind: ResourceQuota
 metadata:
@@ -683,7 +890,11 @@ spec:
     requests.memory: 1Gi
     limits.cpu: '2'
     limits.memory: 2Gi
-`).setIn([referenceForModel(k8sModels.ResourceQuotaModel), 'rq-storageclass'], `
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.ResourceQuotaModel), 'rq-storageclass'],
+    `
 apiVersion: v1
 kind: ResourceQuota
 metadata:
@@ -700,7 +911,11 @@ spec:
     silver.storage-class.kubernetes.io/persistentvolumeclaims: '3'
     bronze.storage-class.kubernetes.io/requests.storage: 1Gi
     bronze.storage-class.kubernetes.io/persistentvolumeclaims: '1'
-`).setIn([referenceForModel(k8sModels.ResourceQuotaModel), 'rq-counts'], `
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.ResourceQuotaModel), 'rq-counts'],
+    `
 apiVersion: v1
 kind: ResourceQuota
 metadata:
@@ -714,13 +929,21 @@ spec:
     secrets: "10"
     services: "10"
     services.loadbalancers: "2"
-`).setIn([referenceForModel(k8sModels.ClusterAutoscalerModel), 'default'], `
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.ClusterAutoscalerModel), 'default'],
+    `
 apiVersion: "autoscaling.openshift.io/v1"
 kind: "ClusterAutoscaler"
 metadata:
   name: "default"
 spec: {}
-`).setIn([referenceForModel(k8sModels.MachineDeploymentModel), 'default'], `
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.MachineDeploymentModel), 'default'],
+    `
 apiVersion: "machine.openshift.io/v1beta1"
 kind: MachineDeployment
 metadata:
@@ -738,7 +961,11 @@ spec:
       providerSpec: {}
       versions:
         kubelet: ""
-`).setIn([referenceForModel(k8sModels.MachineSetModel), 'default'], `
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.MachineSetModel), 'default'],
+    `
 apiVersion: "machine.openshift.io/v1beta1"
 kind: MachineSet
 metadata:
@@ -756,14 +983,22 @@ spec:
       providerSpec: {}
       versions:
         kubelet: ""
-`).setIn([referenceForModel(k8sModels.MachineModel), 'default'], `
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.MachineModel), 'default'],
+    `
 apiVersion: "machine.openshift.io/v1beta1"
 kind: Machine
 metadata:
   name: example
 spec:
   providerSpec: {}
-`).setIn([referenceForModel(k8sModels.MachineConfigPoolModel), 'default'], `
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.MachineConfigPoolModel), 'default'],
+    `
 apiVersion: machineconfiguration.openshift.io/v1
 kind: MachineConfigPool
 metadata:
@@ -775,7 +1010,11 @@ spec:
   machineSelector:
     matchLabels:
       node-role.kubernetes.io/master: ""
-`).setIn([referenceForModel(k8sModels.MachineAutoscalerModel), 'default'], `
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.MachineAutoscalerModel), 'default'],
+    `
 apiVersion: "autoscaling.openshift.io/v1beta1"
 kind: "MachineAutoscaler"
 metadata:
@@ -788,7 +1027,36 @@ spec:
     apiVersion: machine.openshift.io/v1beta1
     kind: MachineSet
     name: worker
-`).setIn([referenceForModel(k8sModels.ConsoleLinkModel), 'default'], `
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.MachineHealthCheckModel), 'default'],
+    `
+apiVersion: machine.openshift.io/v1beta1
+kind: MachineHealthCheck
+metadata:
+  name: example
+  namespace: openshift-machine-api
+spec:
+  selector:
+    matchLabels:
+      machine.openshift.io/cluster-api-cluster: my-cluster
+      machine.openshift.io/cluster-api-machine-role: worker
+      machine.openshift.io/cluster-api-machine-type: worker
+      machine.openshift.io/cluster-api-machineset: my-machine-set
+  unhealthyConditions:
+  - type:    "Ready"
+    status:  "Unknown"
+    timeout: "300s"
+  - type:    "Ready"
+    status:  "False"
+    timeout: "300s"
+  maxUnhealthy: "40%"
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.ConsoleLinkModel), 'default'],
+    `
 apiVersion: console.openshift.io/v1
 kind: ConsoleLink
 metadata:
@@ -796,8 +1064,57 @@ metadata:
 spec:
   href: 'https://www.example.com'
   location: HelpMenu
-  text: Additional help menu link
-`).setIn([referenceForModel(k8sModels.ConsoleCLIDownloadModel), 'default'], `
+  text: Help Menu Link
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.ConsoleLinkModel), 'cl-user-menu'],
+    `
+apiVersion: console.openshift.io/v1
+kind: ConsoleLink
+metadata:
+  name: example-user-menu
+spec:
+  href: 'https://www.example.com'
+  location: UserMenu
+  text: User Menu Link
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.ConsoleLinkModel), 'cl-application-menu'],
+    `
+apiVersion: console.openshift.io/v1
+kind: ConsoleLink
+metadata:
+  name: example-application-menu
+spec:
+  href: 'https://www.example.com'
+  location: ApplicationMenu
+  text: Application Menu Link
+  applicationMenu:
+    section: Example Section
+    imageURL: data:image/svg+xml;base64,PHN2ZyBlbmFibGUtYmFja2dyb3VuZD0ibmV3IDAgMCAyNCAyNCIgaGVpZ2h0PSIyNCIgdmlld0JveD0iMCAwIDI0IDI0IiB3aWR0aD0iMjQiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+PHBhdGggZD0ibTE4LjkgMi4xdjIuMWgtMS43di0yLjFjMC0uMSAwLS4yLS4xLS4zcy0uMi0uMS0uMy0uMWgtMTQuN2MtLjEgMC0uMiAwLS4zLjEgMCAuMS0uMS4yLS4xLjN2MTQuNmMwIC4xIDAgLjIuMS4zcy4yLjEuMy4xaDIuMXYxLjdoLTIuMWMtLjYgMC0xLjEtLjItMS41LS42LS40LS40LS42LS45LS42LTEuNXYtMTQuNmMwLS41LjItMS4xLjYtMS41czEtLjYgMS41LS42aDE0LjZjLjYgMCAxLjEuMiAxLjUuNnMuNyAxIC43IDEuNXptNS4xIDUuMnYxNC42YzAgLjYtLjIgMS4xLS42IDEuNXMtMSAuNi0xLjUuNmgtMTQuNmMtLjYgMC0xLjEtLjItMS41LS42cy0uNi0uOS0uNi0xLjV2LTE0LjZjMC0uNi4yLTEuMS42LTEuNXMuOS0uNiAxLjUtLjZoMTQuNmMuNiAwIDEuMS4yIDEuNS42cy42LjkuNiAxLjV6bS0xLjcgMTQuNnYtMTQuNmMwLS4xIDAtLjItLjEtLjNzLS4yLS4xLS4zLS4xaC0xNC42Yy0uMSAwLS4yIDAtLjMuMXMtLjEuMi0uMS4zdjE0LjZjMCAuMSAwIC4yLjEuM3MuMi4xLjMuMWgxNC42Yy4xIDAgLjIgMCAuMy0uMXMuMS0uMi4xLS4zeiIvPjwvc3ZnPg==
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.ConsoleLinkModel), 'cl-namespace-dashboard'],
+    `
+apiVersion: console.openshift.io/v1
+kind: ConsoleLink
+metadata:
+  name: example-namespace-dashboard
+spec:
+  href: 'https://www.example.com'
+  location: NamespaceDashboard
+  text: Namespace Dashboard Link
+  namespaceDashboard:
+    namespaces:
+      - default
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.ConsoleCLIDownloadModel), 'default'],
+    `
 apiVersion: console.openshift.io/v1
 kind: ConsoleCLIDownload
 metadata:
@@ -810,7 +1127,12 @@ spec:
     Lorem ipsum dolor sit amet, consectetur adipiscing elit. Fusce a lobortis justo, eu suscipit purus.
   links:
     - href: 'https://www.example.com'
-`).setIn([referenceForModel(k8sModels.ConsoleNotificationModel), 'default'], `
+      text: Download Example CLI
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.ConsoleNotificationModel), 'default'],
+    `
 apiVersion: console.openshift.io/v1
 kind: ConsoleNotification
 metadata:
@@ -823,7 +1145,11 @@ spec:
     text: Optional link text
   color: '#fff'
   backgroundColor: '#0088ce'
-`).setIn([referenceForModel(k8sModels.ConsoleExternalLogLinkModel), 'default'], `
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.ConsoleExternalLogLinkModel), 'default'],
+    `
 apiVersion: console.openshift.io/v1
 kind: ConsoleLogLink
 metadata:
@@ -831,18 +1157,54 @@ metadata:
 spec:
   hrefTemplate: 'https://example.com/logs?resourceName=\${resourceName}&containerName=\${containerName}&resourceNamespace=\${resourceNamespace}&podLabels=\${podLabels}'
   text: Example Logs
-`);
+`,
+  )
+  .setIn(
+    [referenceForModel(k8sModels.ConsoleYAMLSampleModel), 'default'],
+    `
+apiVersion: console.openshift.io/v1
+kind: ConsoleYAMLSample
+metadata:
+  name: example
+spec:
+  targetResource:
+    apiVersion: batch/v1
+    kind: Job
+  title: 'Example Job'
+  description: 'An example Job YAML sample'
+  yaml: |
+    apiVersion: batch/v1
+    kind: Job
+    metadata:
+      name: countdown
+    spec:
+      template:
+        metadata:
+          name: countdown
+        spec:
+          containers:
+          - name: counter
+            image: centos:7
+            command:
+            - "bin/bash"
+            - "-c"
+            - "for i in 9 8 7 6 5 4 3 2 1 ; do echo $i ; done"
+          restartPolicy: Never
+`,
+  );
 
-const pluginTemplates = ImmutableMap<GroupVersionKind, ImmutableMap<string, string>>()
-  .withMutations(map => {
-    plugins.registry.getYAMLTemplates().forEach(yt => {
-      const modelRef = referenceForModel(yt.properties.model);
-      const templateName = yt.properties.templateName || 'default';
+const pluginTemplates = ImmutableMap<
+  GroupVersionKind,
+  ImmutableMap<string, string>
+>().withMutations((map) => {
+  plugins.registry.getYAMLTemplates().forEach((yt) => {
+    const modelRef = referenceForModel(yt.properties.model);
+    const templateName = yt.properties.templateName || 'default';
 
-      if (!baseTemplates.hasIn([modelRef, templateName])) {
-        map.setIn([modelRef, templateName], yt.properties.template);
-      }
-    });
+    if (!baseTemplates.hasIn([modelRef, templateName])) {
+      map.setIn([modelRef, templateName], yt.properties.template);
+    }
   });
+});
 
 export const yamlTemplates = baseTemplates.merge(pluginTemplates);
